package com.livelike.flickersearchlibrary

import com.livelike.flickersearchlibrary.api.model.Photo
import com.livelike.flickersearchlibrary.di.Dependencies
import com.livelike.flickersearchlibrary.service.FlickrService
import org.koin.java.KoinJavaComponent.inject

/**
 * Defines Flickr service features.
 */
object Flickr {

    init {
        Dependencies.init()
    }

    private val flickrService: FlickrService by inject(FlickrService::class.java)

    /**
     * Provides search results for given search term.
     * If no search query is provided, empty results will be returned.
     *
     * @param searchQuery [String] the search term for which photo results should be returned.
     * @return [List] of [Photo]s matching the given search term, or empty results if no term is provided.
     */
    suspend fun search(searchQuery: String?) = flickrService.search(searchQuery)

    /**
     * Retrieves recently published photos on Flickr.
     *
     * @return [List] of recently published photos on Flickr.
     */
    suspend fun getRecentPhotos() = flickrService.getRecentPhotos()

}