package com.livelike.flickersearchlibrary.service

import com.livelike.flickersearchlibrary.api.model.Photo

/**
 * Interface for the service providing Flickr features.
 */
interface FlickrService {

    /**
     * Searches for photos and retrieves [List] of [Photo]s.
     * If no search query is provided, empty list will be returned.
     *
     * @param searchQuery [String] text query for searching photos.
     * @return [List] of [Photo]s matching given [searchQuery] or empty list if no query is provided.
     */
    suspend fun search(searchQuery: String?): List<Photo>

    /**
     * Retrieves recently published photos on Flickr.
     *
     * @return [List] of recently published photos on Flickr.
     */
    suspend fun getRecentPhotos(): List<Photo>
}